# specgfx
ZX Spectrum style text and graphics for python

This project has grown out of the joys and frustrations of retrocomputing. I love the aesthetic of 8-bit machines,
I like the simplicity and convenience of their text and graphics, but actually using old versions of BASIC I find myself
missing the modern conveniences of programming languages like Python.

So I wrote a library to produce ZX Spectrum-style text and graphics, for Python.

Documentation is at https://specgfx.readthedocs.io/en/latest/
